--------------------------------------------------------------------
-- Interface Options Panel
--------------------------------------------------------------------


---------------------------
-- reload UI dialog
---------------------------
StaticPopupDialogs["Glance_RELOADUI"] = {
	text = "Reload your User Interface?",
	button1 = TEXT(ACCEPT),
	button2 = TEXT(CANCEL),
	OnAccept = function()
		ReloadUI()
	end,
	OnCancel = function(data, reason)
		if (reason == "timeout") then
			ReloadUI()
		else
			StaticPopupDialogs["Glance_RELOADUI"].reloadAccepted = false
		end
	end,
	OnHide = function()
		if (StaticPopupDialogs["Glance_RELOADUI"].reloadAccepted) then
			ReloadUI();
		end
	end,
	OnShow = function()
		StaticPopupDialogs["Glance_RELOADUI"].reloadAccepted = true;
	end,
	timeout = 5,
	hideOnEscape = 1,
	exclusive = 1,
	whileDead = 1
}

---------------------------
-- update frame scale
---------------------------
function Glance.Functions.updateFrameScale(scale)
	Glance_Local.Options.frameScale = scale
	Glance.Frames.topFrame:SetScale(scale)
	Glance.Functions.moveUI()
	Glance.Functions.updateAll()
end

---------------------------
-- preload checkboxes
---------------------------
function Glance.Functions.setOptionValues()
	for i=1,#Glance.CheckBoxes do
		_G["chk"..i]:SetChecked(Glance_Local.Options[Glance.CheckBoxes[i][4]])
	end
end

---------------------------
-- checkbox onclick
---------------------------
function Glance.Functions.switchOptionValues(btn,val)
	if btn:GetChecked() == nil then
		Glance_Local.Options[val] = false
	else
		Glance_Local.Options[val] = true
	end
	--Glance.Functions.updateAll()
end

---------------------------
-- save profile
---------------------------
function Glance.Functions.saveProfile()
	local hour, min = GetGameTime()
	Glance_Profile.realm = GetRealmName()
	Glance_Profile.name  = UnitName("player")
	Glance_Profile.date  = date("%m/%d/%y")
	Glance_Profile.time  = Glance.Functions.GetHour(hour)..":"..Glance.Functions.GetMin(min).." "..Glance.Functions.GetAMPM(hour).." (S)"
	Glance_Profile.Options = Glance_Local.Options
	Glance_Profile.button  = Glance_Local.button
	for k, v in pairs(Glance.Buttons) do
		if Glance.Buttons[k].save.allowProfile then
			if Glance.Buttons[k].save.perCharacter ~= nil then
				for key, val in pairs(Glance.Buttons[k].save.perCharacter) do
					if Glance_Profile[k] == nil then Glance_Profile[k] = {} end
					Glance_Profile[k][key] = Glance.Buttons[k].save.perCharacter[key]
				end
			end
		end
	end
	StaticPopupDialogs["Glance_Saved"] = {
		text = "Your settings have been saved to the profile.",
		button1 = TEXT(OKAY),
		timeout = 5,
		hideOnEscape = 1,
		exclusive = 1,
		whileDead = 1
	}
	StaticPopup_Show("Glance_Saved")
	_G["Glance_Profile_Text"]:SetText(Glance_Profile.realm.." \\ "..Glance_Profile.name.." on "..Glance_Profile.date.." at "..Glance_Profile.time)
end

---------------------------
-- load profile
---------------------------
function Glance.Functions.loadProfile()
	Glance_Local.Options = Glance_Profile.Options
	Glance_Local.button = Glance_Profile.button
	Glance.Variables.button = Glance_Profile.button
	for k, v in pairs(Glance.Buttons) do
		if Glance.Buttons[k].save.allowProfile then
			if Glance.Buttons[k].save.perCharacter ~= nil then
				for key, val in pairs(Glance.Buttons[k].save.perCharacter) do
					if Glance_Profile[k] ~= nil then 
					Glance.Buttons[k].save.perCharacter[key] = Glance_Profile[k][key]
					end
				end
			end
		end
	end
	Glance.Functions.positionButtons()
	Glance.Functions.updateAll()
	StaticPopupDialogs["Glance_Loaded"] = {
		text = "Your settings have been loaded from the profile.",
		button1 = TEXT(OKAY),
		timeout = 5,
		hideOnEscape = 1,
		exclusive = 1,
		whileDead = 1
	}
	StaticPopup_Show("Glance_Loaded")
end


---------------------------
-- Hour function
---------------------------
function Glance.Functions.GetHour(hour)
	if hour > 12 then
		hour = hour - 12
	end
	if hour == 0 then
		hour = 12
	end
	return hour
end

---------------------------
-- Hour function
---------------------------
function Glance.Functions.GetMin(min)
	if min < 10 then
		return "0"..min
	end
	return min
end

---------------------------
-- DST function
---------------------------
function Glance.Functions.GetAMPM(hour)
	if hour < 12 then
		return "AM"
	else
		return "PM"
	end
end


